@@ -4,7 +4,7 @@ import os
 import sys
 import tempfile
 
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 
 
 PY2 = sys.version_info[0] == 2
@@ -126,7 +126,7 @@ class AtomicWriter(object):
             raise
 
     def get_fileobject(self, dir=None, **kwargs):
-        '''Return the temporary path to use.'''
+        '''Return the temporary file to use.'''
         if dir is None:
             dir = os.path.dirname(self._path)
         return tempfile.NamedTemporaryFile(mode=self._mode, dir=dir,
@@ -134,8 +134,11 @@ class AtomicWriter(object):
 
     def commit(self, f):
         '''Move the temporary file to the target location.'''
+        f.flush()
+        os.fsync(f.fileno())
+
         if self._overwrite:
-            replace_atomic(f.name, self._path)  # atomic
+            replace_atomic(f.name, self._path)
         else:
             move_atomic(f.name, self._path)
 
@@ -152,8 +155,11 @@ def atomic_write(path, writer_cls=AtomicWriter, **cls_kwargs):
             f.write(...)
 
     :param path: The target path to write to.
+    :param writer_cls: The writer class to use. This parameter is useful if you
+        subclassed :py:class:`AtomicWriter` to change some behavior and want to
+        use that new subclass.
 
     Additional keyword arguments are passed to the writer class. See
-    :py:class:`AtomicWriterBase`.
+    :py:class:`AtomicWriter`.
     '''
     return writer_cls(path, **cls_kwargs).open()
